@@ -4,7 +4,7 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, you can obtain one at https://mozilla.org/MPL/2.0/.
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
 #
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
@@ -12,9 +12,15 @@
 SYSTEMTESTTOP=..
 . $SYSTEMTESTTOP/conf.sh
 
-test -r $RANDFILE || $GENRANDOM $RANDOMSIZE $RANDFILE
+$SHELL clean.sh
 
 cp -f ns2/example1.db ns2/example.db
+rm -f ns2/external/K*
+rm -f ns2/external/inline.db.signed
+rm -f ns2/external/inline.db.signed.jnl
+rm -f ns2/internal/K*
+rm -f ns2/internal/inline.db.signed
+rm -f ns2/internal/inline.db.signed.jnl
 
 copy_setports ns1/named.conf.in ns1/named.conf
 copy_setports ns2/named1.conf.in ns2/named.conf
@@ -26,11 +32,11 @@ copy_setports ns5/named.conf.in ns5/named.conf
 # same source of "random" data and we want different keys for
 # internal and external instances of inline.
 #
-$KEYGEN -K ns2/internal -r $RANDFILE -3q inline > /dev/null 2>&1
-$KEYGEN -K ns2/internal -r $RANDFILE -3qfk inline > /dev/null 2>&1
-k1=`$KEYGEN -K ns2/external -r $RANDFILE -3q inline 2> /dev/null`
-k2=`$KEYGEN -K ns2/external -r $RANDFILE -3qfk inline 2> /dev/null`
-$KEYGEN -K ns2/external -r $RANDFILE -3q inline > /dev/null 2>&1
-$KEYGEN -K ns2/external -r $RANDFILE -3qfk inline > /dev/null 2>&1
+$KEYGEN -K ns2/internal -a rsasha256 -q inline > /dev/null 2>&1
+$KEYGEN -K ns2/internal -a rsasha256 -qfk inline > /dev/null 2>&1
+k1=`$KEYGEN -K ns2/external -a rsasha256 -q inline 2> /dev/null`
+k2=`$KEYGEN -K ns2/external -a rsasha256 -qfk inline 2> /dev/null`
+$KEYGEN -K ns2/external -a rsasha256 -q inline > /dev/null 2>&1
+$KEYGEN -K ns2/external -a rsasha256 -qfk inline > /dev/null 2>&1
 test -n "$k1" && rm -f ns2/external/$k1.*
 test -n "$k2" && rm -f ns2/external/$k2.*
