@@ -34,20 +34,11 @@
  */
 
 /*
- * Copyright (C) 1999-2001  Internet Software Consortium.
+ * Copyright (C) 1999-2001, 2016  Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
- *
- * THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM
- * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
- * INTERNET SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
- * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
- * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
- * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
 #ifdef DLZ_POSTGRES
@@ -158,8 +149,6 @@ postgres_makesafe(char *to, const char *from, size_t length)
 	return target - to;
 }
 
-#ifdef ISC_PLATFORM_USETHREADS
-
 /*%
  * Properly cleans up a list of database instances.
  * This function is only used when the driver is compiled for
@@ -187,7 +176,7 @@ postgres_destroy_dblist(db_list_t *dblist)
 		destroy_sqldbinstance(dbi);
 	}
 	/* release memory for the list structure */
-	isc_mem_put(ns_g_mctx, dblist, sizeof(db_list_t));
+	isc_mem_put(named_g_mctx, dblist, sizeof(db_list_t));
 }
 
 /*%
@@ -234,8 +223,6 @@ postgres_find_avail_conn(db_list_t *dblist)
 	return NULL;
 }
 
-#endif /* ISC_PLATFORM_USETHREADS */
-
 /*%
  * Allocates memory for a new string, and then constructs the new
  * string by "escaping" the input string.  The new string is
@@ -255,7 +242,7 @@ postgres_escape_string(const char *instr) {
 
 	len = strlen(instr);
 
-	outstr = isc_mem_allocate(ns_g_mctx ,(2 * len * sizeof(char)) + 1);
+	outstr = isc_mem_allocate(named_g_mctx ,(2 * len * sizeof(char)) + 1);
 	if (outstr == NULL)
 		return NULL;
 
@@ -307,21 +294,10 @@ postgres_get_resultset(const char *zone, const char *record,
 #endif
 
 	/* get db instance / connection */
-#ifdef ISC_PLATFORM_USETHREADS
 
 	/* find an available DBI from the list */
 	dbi = postgres_find_avail_conn((db_list_t *) dbdata);
 
-#else /* ISC_PLATFORM_USETHREADS */
-
-	/*
-	 * only 1 DBI - no need to lock instance lock either
-	 * only 1 thread in the whole process, no possible contention.
-	 */
-	dbi =  (dbinstance_t *) dbdata;
-
-#endif /* ISC_PLATFORM_USETHREADS */
-
 #if 0
 	/* temporary logging message */
 	isc_log_write(dns_lctx, DNS_LOGCATEGORY_DATABASE,
@@ -474,19 +450,19 @@ postgres_get_resultset(const char *zone, const char *record,
 	 */
 	switch(query) {
 	case ALLNODES:
-		querystring = build_querystring(ns_g_mctx, dbi->allnodes_q);
+		querystring = build_querystring(named_g_mctx, dbi->allnodes_q);
 		break;
 	case ALLOWXFR:
-		querystring = build_querystring(ns_g_mctx, dbi->allowxfr_q);
+		querystring = build_querystring(named_g_mctx, dbi->allowxfr_q);
 		break;
 	case AUTHORITY:
-		querystring = build_querystring(ns_g_mctx, dbi->authority_q);
+		querystring = build_querystring(named_g_mctx, dbi->authority_q);
 		break;
 	case FINDZONE:
-		querystring = build_querystring(ns_g_mctx, dbi->findzone_q);
+		querystring = build_querystring(named_g_mctx, dbi->findzone_q);
 		break;
 	case LOOKUP:
-		querystring = build_querystring(ns_g_mctx, dbi->lookup_q);
+		querystring = build_querystring(named_g_mctx, dbi->lookup_q);
 		break;
 	default:
 		/*
@@ -598,17 +574,15 @@ postgres_get_resultset(const char *zone, const char *record,
 
 	/* free dbi->zone string */
 	if (dbi->zone != NULL)
-		isc_mem_free(ns_g_mctx, dbi->zone);
+		isc_mem_free(named_g_mctx, dbi->zone);
 
 	/* free dbi->record string */
 	if (dbi->record != NULL)
-		isc_mem_free(ns_g_mctx, dbi->record);
+		isc_mem_free(named_g_mctx, dbi->record);
 
 	/* free dbi->client string */
 	if (dbi->client != NULL)
-		isc_mem_free(ns_g_mctx, dbi->client);
-
-#ifdef ISC_PLATFORM_USETHREADS
+		isc_mem_free(named_g_mctx, dbi->client);
 
 #if 0
 	/* temporary logging message */
@@ -620,11 +594,9 @@ postgres_get_resultset(const char *zone, const char *record,
 	/* release the lock so another thread can use this dbi */
 	isc_mutex_unlock(&dbi->instance_lock);
 
-#endif /* ISC_PLATFORM_USETHREADS */
-
 	/* release query string */
 	if (querystring  != NULL)
-		isc_mem_free(ns_g_mctx, querystring );
+		isc_mem_free(named_g_mctx, querystring );
 
 #if 0
 	/* temporary logging message */
@@ -705,7 +677,7 @@ postgres_process_rs(dns_sdlzlookup_t *lookup, PGresult *rs)
 			 * allocate string memory, allow for NULL to
 			 * term string
 			 */
-			tmpString = isc_mem_allocate(ns_g_mctx, len + 1);
+			tmpString = isc_mem_allocate(named_g_mctx, len + 1);
 			if (tmpString == NULL) {
 				/* major bummer, need more ram */
 				isc_log_write(dns_lctx,
@@ -740,7 +712,7 @@ postgres_process_rs(dns_sdlzlookup_t *lookup, PGresult *rs)
 			result = dns_sdlz_putrr(lookup, PQgetvalue(rs, i, 1),
 						ttl, tmpString);
 			/* done, get rid of this thing. */
-			isc_mem_free(ns_g_mctx, tmpString);
+			isc_mem_free(named_g_mctx, tmpString);
 		}
 		/* I sure hope we were successful */
 		if (result != ISC_R_SUCCESS) {
@@ -935,7 +907,7 @@ postgres_allnodes(const char *zone, void *driverarg, void *dbdata,
 				len += strlen(PQgetvalue(rs, i, j)) + 1;
 			}
 			/* allocate memory, allow for NULL to term string */
-			tmpString = isc_mem_allocate(ns_g_mctx, len + 1);
+			tmpString = isc_mem_allocate(named_g_mctx, len + 1);
 			if (tmpString == NULL) {	/* we need more ram. */
 				isc_log_write(dns_lctx,
 					      DNS_LOGCATEGORY_DATABASE,
@@ -958,7 +930,7 @@ postgres_allnodes(const char *zone, void *driverarg, void *dbdata,
 						     PQgetvalue(rs, i, 2),
 						     PQgetvalue(rs, i, 1),
 						     ttl, tmpString);
-			isc_mem_free(ns_g_mctx, tmpString);
+			isc_mem_free(named_g_mctx, tmpString);
 		}
 		/* if we weren't successful, log err msg */
 		if (result != ISC_R_SUCCESS) {
@@ -1067,15 +1039,12 @@ postgres_create(const char *dlzname, unsigned int argc, char *argv[],
 	dbinstance_t *dbi = NULL;
 	unsigned int j;
 
-#ifdef ISC_PLATFORM_USETHREADS
 	/* if multi-threaded, we need a few extra variables. */
 	int dbcount;
 	db_list_t *dblist = NULL;
 	int i;
 	char *endp;
 
-#endif /* ISC_PLATFORM_USETHREADS */
-
 	UNUSED(driverarg);
 	UNUSED(dlzname);
 
@@ -1083,17 +1052,10 @@ postgres_create(const char *dlzname, unsigned int argc, char *argv[],
 	srand( (unsigned)time( NULL ) );
 
 
-#ifdef ISC_PLATFORM_USETHREADS
 	/* if debugging, let user know we are multithreaded. */
 	isc_log_write(dns_lctx, DNS_LOGCATEGORY_DATABASE,
 		      DNS_LOGMODULE_DLZ, ISC_LOG_DEBUG(1),
 		      "Postgres driver running multithreaded");
-#else /* ISC_PLATFORM_USETHREADS */
-	/* if debugging, let user know we are single threaded. */
-	isc_log_write(dns_lctx, DNS_LOGCATEGORY_DATABASE,
-		      DNS_LOGMODULE_DLZ, ISC_LOG_DEBUG(1),
-		      "Postgres driver running single threaded");
-#endif /* ISC_PLATFORM_USETHREADS */
 
 	/* verify we have at least 5 arg's passed to the driver */
 	if (argc < 5) {
@@ -1114,7 +1076,6 @@ postgres_create(const char *dlzname, unsigned int argc, char *argv[],
 	}
 
 	/* multithreaded build can have multiple DB connections */
-#ifdef ISC_PLATFORM_USETHREADS
 
 	/* check how many db connections we should create */
 	dbcount = strtol(argv[1], &endp, 10);
@@ -1127,7 +1088,7 @@ postgres_create(const char *dlzname, unsigned int argc, char *argv[],
 	}
 
 	/* allocate memory for database connection list */
-	dblist = isc_mem_get(ns_g_mctx, sizeof(db_list_t));
+	dblist = isc_mem_get(named_g_mctx, sizeof(db_list_t));
 	if (dblist == NULL)
 		return (ISC_R_NOMEMORY);
 
@@ -1140,27 +1101,25 @@ postgres_create(const char *dlzname, unsigned int argc, char *argv[],
 	 */
 	for (i=0; i < dbcount; i++) {
 
-#endif /* ISC_PLATFORM_USETHREADS */
-
 		/* how many queries were passed in from config file? */
 		switch(argc) {
 		case 5:
-			result = build_sqldbinstance(ns_g_mctx, NULL, NULL,
+			result = build_sqldbinstance(named_g_mctx, NULL, NULL,
 						     NULL, argv[3], argv[4],
 						     NULL, &dbi);
 			break;
 		case 6:
-			result = build_sqldbinstance(ns_g_mctx, NULL, NULL,
+			result = build_sqldbinstance(named_g_mctx, NULL, NULL,
 						     argv[5], argv[3], argv[4],
 						     NULL, &dbi);
 			break;
 		case 7:
-			result = build_sqldbinstance(ns_g_mctx, argv[6], NULL,
+			result = build_sqldbinstance(named_g_mctx, argv[6], NULL,
 						     argv[5], argv[3], argv[4],
 						     NULL, &dbi);
 			break;
 		case 8:
-			result = build_sqldbinstance(ns_g_mctx, argv[6],
+			result = build_sqldbinstance(named_g_mctx, argv[6],
 						     argv[7], argv[5], argv[3],
 						     argv[4], NULL, &dbi);
 			break;
@@ -1183,14 +1142,10 @@ postgres_create(const char *dlzname, unsigned int argc, char *argv[],
 			goto cleanup;
 		}
 
-#ifdef ISC_PLATFORM_USETHREADS
-
 		/* when multithreaded, build a list of DBI's */
 		ISC_LINK_INIT(dbi, link);
 		ISC_LIST_APPEND(*dblist, dbi, link);
 
-#endif
-
 		/* create and set db connection */
 		dbi->dbconn = PQconnectdb(argv[2]);
 		/*
@@ -1213,8 +1168,6 @@ postgres_create(const char *dlzname, unsigned int argc, char *argv[],
 			PQreset((PGconn *) dbi->dbconn);
 
 
-#ifdef ISC_PLATFORM_USETHREADS
-
 		/*
 		 * if multi threaded, let user know which connection
 		 * failed.  user could be attempting to create 10 db
@@ -1238,30 +1191,11 @@ postgres_create(const char *dlzname, unsigned int argc, char *argv[],
 		/* set dbdata to the list we created. */
 	*dbdata = dblist;
 
-#else /* ISC_PLATFORM_USETHREADS */
-	/* if single threaded, just let user know we couldn't connect. */
-	if (PQstatus((PGconn *) dbi->dbconn) != CONNECTION_OK) {
-		isc_log_write(dns_lctx, DNS_LOGCATEGORY_DATABASE,
-			      DNS_LOGMODULE_DLZ, ISC_LOG_ERROR,
-			      "Postgres driver failed to create database "
-			      "connection after 4 attempts");
-		goto cleanup;
-	}
-
-	/*
-	 * single threaded build can only use 1 db connection, return
-	 * it via dbdata
-	 */
-	*dbdata = dbi;
-
-#endif /* ISC_PLATFORM_USETHREADS */
-
 	/* hey, we got through all of that ok, return success. */
 	return(ISC_R_SUCCESS);
 
  cleanup:
 
-#ifdef ISC_PLATFORM_USETHREADS
 	/*
 	 * if multithreaded, we could fail because only 1 connection
 	 * couldn't be made.  We should cleanup the other successful
@@ -1269,11 +1203,6 @@ postgres_create(const char *dlzname, unsigned int argc, char *argv[],
 	 */
 	postgres_destroy_dblist(dblist);
 
-#else /* ISC_PLATFORM_USETHREADS */
-	if (dbi != NULL)
-		destroy_sqldbinstance(dbi);
-
-#endif /* ISC_PLATFORM_USETHREADS */
 	return(ISC_R_FAILURE);
 }
 
@@ -1286,29 +1215,9 @@ postgres_create(const char *dlzname, unsigned int argc, char *argv[],
 static void
 postgres_destroy(void *driverarg, void *dbdata)
 {
-
-#ifdef ISC_PLATFORM_USETHREADS
-
 	UNUSED(driverarg);
 	/* cleanup the list of DBI's */
 	postgres_destroy_dblist((db_list_t *) dbdata);
-
-#else /* ISC_PLATFORM_USETHREADS */
-
-	dbinstance_t *dbi;
-
-	UNUSED(driverarg);
-
-	dbi = (dbinstance_t *) dbdata;
-
-	/* release DB connection */
-	if (dbi->dbconn != NULL)
-		PQfinish((PGconn *) dbi->dbconn);
-
-	/* destroy single DB instance */
-	destroy_sqldbinstance(dbi);
-
-#endif /* ISC_PLATFORM_USETHREADS */
 }
 
 /* pointers to all our runtime methods. */
@@ -1356,7 +1265,7 @@ dlz_postgres_init(void) {
 				  DNS_SDLZFLAG_RELATIVEOWNER |
 				  DNS_SDLZFLAG_RELATIVERDATA |
 				  DNS_SDLZFLAG_THREADSAFE,
-				  ns_g_mctx, &dlz_postgres);
+				  named_g_mctx, &dlz_postgres);
 	/* if we can't register the driver, there are big problems. */
 	if (result != ISC_R_SUCCESS) {
 		UNEXPECTED_ERROR(__FILE__, __LINE__,
