@@ -13,6 +13,7 @@
 #ifndef DNS_RPZ_H
 #define DNS_RPZ_H 1
 
+#include <inttypes.h>
 #include <stdbool.h>
 
 #include <isc/deprecated.h>
@@ -78,15 +79,12 @@ typedef enum {
 
 typedef uint8_t	    dns_rpz_num_t;
 
-#define DNS_RPZ_MAX_ZONES   32
-#if DNS_RPZ_MAX_ZONES > 32
-# if DNS_RPZ_MAX_ZONES > 64
-#  error "rpz zone bit masks must fit in a word"
-# endif
+#define DNS_RPZ_MAX_ZONES   64
+/*
+ * Type dns_rpz_zbits_t must be an unsigned int wide enough to contain
+ * at least DNS_RPZ_MAX_ZONES bits.
+ */
 typedef uint64_t	    dns_rpz_zbits_t;
-#else
-typedef uint32_t	    dns_rpz_zbits_t;
-#endif
 
 #define DNS_RPZ_ALL_ZBITS   ((dns_rpz_zbits_t)-1)
 
@@ -99,7 +97,7 @@ typedef uint32_t	    dns_rpz_zbits_t;
  * Avoid hassles with (1<<33) or (1<<65)
  */
 #define DNS_RPZ_ZMASK(n)    ((dns_rpz_zbits_t)((((n) >= DNS_RPZ_MAX_ZONES-1) ? \
-						0 : (1<<((n)+1))) -1))
+						0 : (1ULL<<((n)+1))) -1))
 
 /*
  * The trigger counter type.
@@ -426,3 +424,4 @@ dns_rpz_find_name(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 ISC_LANG_ENDDECLS
 
 #endif /* DNS_RPZ_H */
+
