@@ -13,10 +13,9 @@
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
 #include <sys/stat.h>
-#ifdef HAVE_INTTYPES_H
-#include <inttypes.h> /* uintptr_t */
-#endif
 
 #include <isc/crc64.h>
 #include <isc/file.h>
@@ -101,16 +100,16 @@ static char FILE_VERSION[32] = "\0";
 
 struct file_header {
 	char version1[32];
-	isc_uint64_t first_node_offset;	/* usually 1024 */
+	uint64_t first_node_offset;	/* usually 1024 */
 	/*
 	 * information about the system on which the map file was generated
 	 * will be used to tell if we can load the map file or not
 	 */
-	isc_uint32_t ptrsize;
+	uint32_t ptrsize;
 	unsigned int bigendian:1;	/* big or little endian system */
 	unsigned int rdataset_fixed:1;	/* compiled with --enable-rrset-fixed */
 	unsigned int nodecount;		/* shadow from rbt structure */
-	isc_uint64_t crc;
+	uint64_t crc;
 	char version2[32];  		/* repeated; must match version1 */
 };
 
@@ -137,21 +136,21 @@ static isc_result_t
 dns_rbt_zero_header(FILE *file);
 
 static isc_result_t
-write_header(FILE *file, dns_rbt_t *rbt, isc_uint64_t first_node_offset,
-	     isc_uint64_t crc);
+write_header(FILE *file, dns_rbt_t *rbt, uint64_t first_node_offset,
+	     uint64_t crc);
 
-static isc_boolean_t
+static bool
 match_header_version(file_header_t *header);
 
 static isc_result_t
 serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 	       uintptr_t right, uintptr_t down, uintptr_t parent,
-	       uintptr_t data, isc_uint64_t *crc);
+	       uintptr_t data, uint64_t *crc);
 
 static isc_result_t
 serialize_nodes(FILE *file, dns_rbtnode_t *node, uintptr_t parent,
 		dns_rbtdatawriter_t datawriter, void *writer_arg,
-		uintptr_t *where, isc_uint64_t *crc);
+		uintptr_t *where, uint64_t *crc);
 
 /*
  * The following functions allow you to get the actual address of a pointer
@@ -215,8 +214,8 @@ getdata(dns_rbtnode_t *node, file_header_t *header) {
 #define OLDNAMELEN(node)        ((node)->oldnamelen)
 #define OFFSETLEN(node)         ((node)->offsetlen)
 #define ATTRS(node)             ((node)->attributes)
-#define IS_ROOT(node)           ISC_TF((node)->is_root == 1)
-#define FINDCALLBACK(node)      ISC_TF((node)->find_callback == 1)
+#define IS_ROOT(node)           ((node)->is_root)
+#define FINDCALLBACK(node)      ((node)->find_callback)
 
 /*%
  * Structure elements from the rbtdb.c, not
@@ -417,14 +416,14 @@ static isc_result_t
 treefix(dns_rbt_t *rbt, void *base, size_t size,
 	dns_rbtnode_t *n, const dns_name_t *name,
 	dns_rbtdatafixer_t datafixer, void *fixer_arg,
-	isc_uint64_t *crc);
+	uint64_t *crc);
 
 static void
-deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, isc_boolean_t unhash,
+deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, bool unhash,
 	       dns_rbtnode_t **nodep);
 
 static void
-printnodename(dns_rbtnode_t *node, isc_boolean_t quoted, FILE *f);
+printnodename(dns_rbtnode_t *node, bool quoted, FILE *f);
 
 static void
 freenode(dns_rbt_t *rbt, dns_rbtnode_t **nodep);
@@ -471,8 +470,8 @@ init_file_version(void) {
  * here.
  */
 static isc_result_t
-write_header(FILE *file, dns_rbt_t *rbt, isc_uint64_t first_node_offset,
-	     isc_uint64_t crc)
+write_header(FILE *file, dns_rbt_t *rbt, uint64_t first_node_offset,
+	     uint64_t crc)
 {
 	file_header_t header;
 	isc_result_t result;
@@ -484,7 +483,7 @@ write_header(FILE *file, dns_rbt_t *rbt, isc_uint64_t first_node_offset,
 	memmove(header.version1, FILE_VERSION, sizeof(header.version1));
 	memmove(header.version2, FILE_VERSION, sizeof(header.version2));
 	header.first_node_offset = first_node_offset;
-	header.ptrsize = (isc_uint32_t) sizeof(void *);
+	header.ptrsize = (uint32_t) sizeof(void *);
 	header.bigendian = (1 == htonl(1)) ? 1 : 0;
 
 #ifdef DNS_RDATASET_FIXED
@@ -510,7 +509,7 @@ write_header(FILE *file, dns_rbt_t *rbt, isc_uint64_t first_node_offset,
 	return (result);
 }
 
-static isc_boolean_t
+static bool
 match_header_version(file_header_t *header) {
 	RUNTIME_CHECK(isc_once_do(&once, init_file_version) == ISC_R_SUCCESS);
 
@@ -519,16 +518,16 @@ match_header_version(file_header_t *header) {
 	    memcmp(header->version2, FILE_VERSION,
 		   sizeof(header->version1)) != 0)
 	{
-		return (ISC_FALSE);
+		return (false);
 	}
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 static isc_result_t
 serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 	       uintptr_t right, uintptr_t down, uintptr_t parent,
-	       uintptr_t data, isc_uint64_t *crc)
+	       uintptr_t data, uint64_t *crc)
 {
 	dns_rbtnode_t temp_node;
 	off_t file_position;
@@ -598,9 +597,9 @@ serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 	hexdump("node data", node_data, datasize);
 #endif
 
-	isc_crc64_update(crc, (const isc_uint8_t *) &temp_node,
+	isc_crc64_update(crc, (const uint8_t *) &temp_node,
 			 sizeof(dns_rbtnode_t));
-	isc_crc64_update(crc, (const isc_uint8_t *) node_data, datasize);
+	isc_crc64_update(crc, (const uint8_t *) node_data, datasize);
 
  cleanup:
 	return (result);
@@ -609,7 +608,7 @@ serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 static isc_result_t
 serialize_nodes(FILE *file, dns_rbtnode_t *node, uintptr_t parent,
 		dns_rbtdatawriter_t datawriter, void *writer_arg,
-		uintptr_t *where, isc_uint64_t *crc)
+		uintptr_t *where, uint64_t *crc)
 {
 	uintptr_t left = 0, right = 0, down = 0, data = 0;
 	off_t location = 0, offset_adjust;
@@ -686,7 +685,7 @@ dns_rbt_serialize_tree(FILE *file, dns_rbt_t *rbt,
 {
 	isc_result_t result;
 	off_t header_position, node_position, end_position;
-	isc_uint64_t crc;
+	uint64_t crc;
 
 	REQUIRE(file != NULL);
 
@@ -738,7 +737,7 @@ dns_rbt_serialize_tree(FILE *file, dns_rbt_t *rbt,
 static isc_result_t
 treefix(dns_rbt_t *rbt, void *base, size_t filesize, dns_rbtnode_t *n,
 	const dns_name_t *name, dns_rbtdatafixer_t datafixer,
-	void *fixer_arg, isc_uint64_t *crc)
+	void *fixer_arg, uint64_t *crc)
 {
 	isc_result_t result = ISC_R_SUCCESS;
 	dns_fixedname_t fixed;
@@ -838,9 +837,9 @@ treefix(dns_rbt_t *rbt, void *base, size_t filesize, dns_rbtnode_t *n,
 		sizeof(dns_rbtnode_t));
 	hexdump("node data", node_data, datasize);
 #endif
-	isc_crc64_update(crc, (const isc_uint8_t *) &header,
+	isc_crc64_update(crc, (const uint8_t *) &header,
 			sizeof(dns_rbtnode_t));
-	isc_crc64_update(crc, (const isc_uint8_t *) node_data,
+	isc_crc64_update(crc, (const uint8_t *) node_data,
 			datasize);
 
  cleanup:
@@ -857,7 +856,7 @@ dns_rbt_deserialize_tree(void *base_address, size_t filesize,
 	isc_result_t result = ISC_R_SUCCESS;
 	file_header_t *header;
 	dns_rbt_t *rbt = NULL;
-	isc_uint64_t crc;
+	uint64_t crc;
 	unsigned int host_big_endian;
 
 	REQUIRE(originp == NULL || *originp == NULL);
@@ -888,7 +887,7 @@ dns_rbt_deserialize_tree(void *base_address, size_t filesize,
 	}
 #endif
 
-	if (header->ptrsize != (isc_uint32_t) sizeof(void *)) {
+	if (header->ptrsize != (uint32_t) sizeof(void *)) {
 		result = ISC_R_INVALIDFILE;
 		goto cleanup;
 	}
@@ -1001,7 +1000,7 @@ dns_rbt_destroy2(dns_rbt_t **rbtp, unsigned int quantum) {
 
 	rbt = *rbtp;
 
-	deletetreeflat(rbt, quantum, ISC_FALSE, &rbt->root);
+	deletetreeflat(rbt, quantum, false, &rbt->root);
 	if (rbt->root != NULL)
 		return (ISC_R_QUOTA);
 
@@ -1038,7 +1037,7 @@ dns_rbt_hashsize(dns_rbt_t *rbt) {
 
 static inline isc_result_t
 chain_name(dns_rbtnodechain_t *chain, dns_name_t *name,
-	   isc_boolean_t include_chain_end)
+	   bool include_chain_end)
 {
 	dns_name_t nodename;
 	isc_result_t result = ISC_R_SUCCESS;
@@ -1566,7 +1565,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 						  nlabels - tlabels,
 						  hlabels + tlabels,
 						  &hash_name);
-			hash = dns_name_fullhash(&hash_name, ISC_FALSE);
+			hash = dns_name_fullhash(&hash_name, false);
 			dns_name_getlabelsequence(search_name,
 						  nlabels - tlabels,
 						  tlabels, &hash_name);
@@ -1685,7 +1684,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 				    FINDCALLBACK(current)) {
 					result = chain_name(chain,
 							    callback_name,
-							    ISC_FALSE);
+							    false);
 					if (result != ISC_R_SUCCESS) {
 						dns_rbtnodechain_reset(chain);
 						return (result);
@@ -1739,7 +1738,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 		chain->level_matches = chain->level_count;
 
 		if (foundname != NULL)
-			result = chain_name(chain, foundname, ISC_TRUE);
+			result = chain_name(chain, foundname, true);
 		else
 			result = ISC_R_SUCCESS;
 
@@ -1776,7 +1775,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 				chain->level_count = chain->level_matches + 1;
 
 				result = chain_name(chain, foundname,
-						    ISC_FALSE);
+						    false);
 
 				chain->level_count = saved_count;
 			} else
@@ -1982,7 +1981,7 @@ dns_rbt_findname(dns_rbt_t *rbt, const dns_name_t *name, unsigned int options,
  */
 isc_result_t
 dns_rbt_deletename(dns_rbt_t *rbt, const dns_name_t *name,
-		   isc_boolean_t recurse)
+		   bool recurse)
 {
 	dns_rbtnode_t *node = NULL;
 	isc_result_t result;
@@ -2056,7 +2055,7 @@ dns_rbt_deletename(dns_rbt_t *rbt, const dns_name_t *name,
  * succeeds. It still returns isc_result_t, though, so the API wouldn't change.
  */
 isc_result_t
-dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, isc_boolean_t recurse)
+dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, bool recurse)
 {
 	dns_rbtnode_t *parent;
 
@@ -2067,7 +2066,7 @@ dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, isc_boolean_t recurse)
 	if (DOWN(node) != NULL) {
 		if (recurse) {
 			PARENT(DOWN(node)) = NULL;
-			deletetreeflat(rbt, 0, ISC_TRUE, &DOWN(node));
+			deletetreeflat(rbt, 0, true, &DOWN(node));
 		} else {
 			if (DATA(node) != NULL && rbt->data_deleter != NULL)
 				rbt->data_deleter(DATA(node), rbt->deleter_arg);
@@ -2106,7 +2105,7 @@ dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, isc_boolean_t recurse)
 #if DNS_RBT_USEMAGIC
 	node->magic = 0;
 #endif
-	dns_rbtnode_refdestroy(node);
+	isc_refcount_destroy(&node->references);
 
 	freenode(rbt, &node);
 
@@ -2218,7 +2217,7 @@ create_node(isc_mem_t *mctx, const dns_name_t *name, dns_rbtnode_t **nodep) {
 	LOCKNUM(node) = 0;
 	WILD(node) = 0;
 	DIRTY(node) = 0;
-	dns_rbtnode_refinit(node, 0);
+	isc_refcount_init(&node->references, 0);
 	node->find_callback = 0;
 	node->nsec = DNS_RBT_NSEC_NORMAL;
 
@@ -2262,7 +2261,7 @@ hash_add_node(dns_rbt_t *rbt, dns_rbtnode_t *node, const dns_name_t *name) {
 
 	REQUIRE(name != NULL);
 
-	HASHVAL(node) = dns_name_fullhash(name, ISC_FALSE);
+	HASHVAL(node) = dns_name_fullhash(name, false);
 
 	hash = HASHVAL(node) % rbt->hashsize;
 	HASHNEXT(node) = rbt->hashtable[hash];
@@ -2619,8 +2618,8 @@ deletefromlevel(dns_rbtnode_t *item, dns_rbtnode_t **rootp) {
 
 		if (IS_ROOT(item)) {
 			*rootp = successor;
-			successor->is_root = ISC_TRUE;
-			item->is_root = ISC_FALSE;
+			successor->is_root = true;
+			item->is_root = false;
 
 		} else
 			if (LEFT(PARENT(item)) == item)
@@ -2790,7 +2789,7 @@ freenode(dns_rbt_t *rbt, dns_rbtnode_t **nodep) {
 }
 
 static void
-deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, isc_boolean_t unhash,
+deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, bool unhash,
 	       dns_rbtnode_t **nodep)
 {
 	dns_rbtnode_t *root = *nodep;
@@ -2863,31 +2862,31 @@ dns__rbt_getheight(dns_rbt_t *rbt) {
 	return (getheight_helper(rbt->root));
 }
 
-static isc_boolean_t
+static bool
 check_properties_helper(dns_rbtnode_t *node) {
 	if (node == NULL)
-		return (ISC_TRUE);
+		return (true);
 
 	if (IS_RED(node)) {
 		/* Root nodes must be BLACK. */
 		if (IS_ROOT(node))
-			return (ISC_FALSE);
+			return (false);
 
 		/* Both children of RED nodes must be BLACK. */
 		if (IS_RED(LEFT(node)) || IS_RED(RIGHT(node)))
-			return (ISC_FALSE);
+			return (false);
 	}
 
 	if ((DOWN(node) != NULL) && (!IS_ROOT(DOWN(node))))
-		return (ISC_FALSE);
+		return (false);
 
 	if (IS_ROOT(node)) {
 		if ((PARENT(node) != NULL) &&
 		    (DOWN(PARENT(node)) != node))
-			return (ISC_FALSE);
+			return (false);
 
 		if (get_upper_node(node) != PARENT(node))
-			return (ISC_FALSE);
+			return (false);
 	}
 
 	/* If node is assigned to the down_ pointer of its parent, it is
@@ -2897,7 +2896,7 @@ check_properties_helper(dns_rbtnode_t *node) {
 	     (DOWN(PARENT(node)) == node)) &&
 	    (!IS_ROOT(node)))
 	{
-		return (ISC_FALSE);
+		return (false);
 	}
 
 	/* Repeat tests with this node's children. */
@@ -2906,42 +2905,42 @@ check_properties_helper(dns_rbtnode_t *node) {
 		check_properties_helper(DOWN(node)));
 }
 
-static isc_boolean_t
+static bool
 check_black_distance_helper(dns_rbtnode_t *node, size_t *distance) {
 	size_t dl, dr, dd;
 
 	if (node == NULL) {
 		*distance = 1;
-		return (ISC_TRUE);
+		return (true);
 	}
 
 	if (!check_black_distance_helper(LEFT(node), &dl))
-		return (ISC_FALSE);
+		return (false);
 
 	if (!check_black_distance_helper(RIGHT(node), &dr))
-		return (ISC_FALSE);
+		return (false);
 
 	if (!check_black_distance_helper(DOWN(node), &dd))
-		return (ISC_FALSE);
+		return (false);
 
 	/* Left and right side black node counts must match. */
 	if (dl != dr)
-		return (ISC_FALSE);
+		return (false);
 
 	if (IS_BLACK(node))
 		dl++;
 
 	*distance = dl;
 
-	return (ISC_TRUE);
+	return (true);
 }
 
-isc_boolean_t
+bool
 dns__rbt_checkproperties(dns_rbt_t *rbt) {
 	size_t dd;
 
 	if (!check_properties_helper(rbt->root))
-		return (ISC_FALSE);
+		return (false);
 
 	/* Path from a given node to all its leaves must contain the
 	 * same number of BLACK child nodes. This is done separately
@@ -2964,7 +2963,7 @@ dns_rbt_indent(FILE *f, int depth) {
 void
 dns_rbt_printnodeinfo(dns_rbtnode_t *n, FILE *f) {
 	fprintf(f, "Node info for nodename: ");
-	printnodename(n, ISC_TRUE, f);
+	printnodename(n, true, f);
 	fprintf(f, "\n");
 
 	fprintf(f, "n = %p\n", n);
@@ -2986,7 +2985,7 @@ dns_rbt_printnodeinfo(dns_rbtnode_t *n, FILE *f) {
 }
 
 static void
-printnodename(dns_rbtnode_t *node, isc_boolean_t quoted, FILE *f) {
+printnodename(dns_rbtnode_t *node, bool quoted, FILE *f) {
 	isc_region_t r;
 	dns_name_t name;
 	char buffer[DNS_NAME_FORMATSIZE];
@@ -3014,7 +3013,7 @@ print_text_helper(dns_rbtnode_t *root, dns_rbtnode_t *parent,
 	dns_rbt_indent(f, depth);
 
 	if (root != NULL) {
-		printnodename(root, ISC_TRUE, f);
+		printnodename(root, true, f);
 		fprintf(f, " (%s, %s", direction,
 			IS_RED(root) ? "RED" : "BLACK");
 
@@ -3024,7 +3023,7 @@ print_text_helper(dns_rbtnode_t *root, dns_rbtnode_t *parent,
 
 			fprintf(f, " (BAD parent pointer! -> ");
 			if (PARENT(root) != NULL)
-				printnodename(PARENT(root), ISC_TRUE, f);
+				printnodename(PARENT(root), true, f);
 			else
 				fprintf(f, "NULL");
 			fprintf(f, ")");
@@ -3068,7 +3067,7 @@ dns_rbt_printtext(dns_rbt_t *rbt,
 
 static int
 print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
-		 isc_boolean_t show_pointers, FILE *f)
+		 bool show_pointers, FILE *f)
 {
 	unsigned int l, r, d;
 
@@ -3082,7 +3081,7 @@ print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
 	*nodecount += 1;
 
 	fprintf(f, "node%u[label = \"<f0> |<f1> ", *nodecount);
-	printnodename(node, ISC_FALSE, f);
+	printnodename(node, false, f);
 	fprintf(f, "|<f2>");
 
 	if (show_pointers)
@@ -3120,7 +3119,7 @@ print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
 }
 
 void
-dns_rbt_printdot(dns_rbt_t *rbt, isc_boolean_t show_pointers, FILE *f) {
+dns_rbt_printdot(dns_rbt_t *rbt, bool show_pointers, FILE *f) {
 	unsigned int nodecount = 0;
 
 	REQUIRE(VALID_RBT(rbt));
@@ -3187,7 +3186,7 @@ dns_rbtnodechain_current(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 	if (origin != NULL) {
 		if (chain->level_count > 0)
-			result = chain_name(chain, origin, ISC_FALSE);
+			result = chain_name(chain, origin, false);
 		else
 			result = dns_name_copy(dns_rootname, origin, NULL);
 	}
@@ -3201,7 +3200,7 @@ dns_rbtnodechain_prev(dns_rbtnodechain_t *chain, dns_name_t *name,
 {
 	dns_rbtnode_t *current, *previous, *predecessor;
 	isc_result_t result = ISC_R_SUCCESS;
-	isc_boolean_t new_origin = ISC_FALSE;
+	bool new_origin = false;
 
 	REQUIRE(VALID_CHAIN(chain) && chain->end != NULL);
 
@@ -3269,7 +3268,7 @@ dns_rbtnodechain_prev(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 			/* XXX DCL probably needs work on the concept */
 			if (origin != NULL)
-				new_origin = ISC_TRUE;
+				new_origin = true;
 		}
 
 	} else if (chain->level_count > 0) {
@@ -3290,7 +3289,7 @@ dns_rbtnodechain_prev(dns_rbtnodechain_t *chain, dns_name_t *name,
 		 */
 		if (origin != NULL &&
 		    (chain->level_count > 0 || OFFSETLEN(predecessor) > 1))
-			new_origin = ISC_TRUE;
+			new_origin = true;
 	}
 
 	if (predecessor != NULL) {
@@ -3318,7 +3317,7 @@ dns_rbtnodechain_down(dns_rbtnodechain_t *chain, dns_name_t *name,
 {
 	dns_rbtnode_t *current, *successor;
 	isc_result_t result = ISC_R_SUCCESS;
-	isc_boolean_t new_origin = ISC_FALSE;
+	bool new_origin = false;
 
 	REQUIRE(VALID_CHAIN(chain) && chain->end != NULL);
 
@@ -3334,7 +3333,7 @@ dns_rbtnodechain_down(dns_rbtnodechain_t *chain, dns_name_t *name,
 		 */
 		if (chain->level_count > 0 ||
 		    OFFSETLEN(current) > 1)
-			new_origin = ISC_TRUE;
+			new_origin = true;
 
 		ADD_LEVEL(chain, current);
 		current = DOWN(current);
@@ -3362,7 +3361,7 @@ dns_rbtnodechain_down(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 		if (new_origin) {
 			if (origin != NULL)
-				result = chain_name(chain, origin, ISC_FALSE);
+				result = chain_name(chain, origin, false);
 
 			if (result == ISC_R_SUCCESS)
 				result = DNS_R_NEWORIGIN;
@@ -3425,7 +3424,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 {
 	dns_rbtnode_t *current, *previous, *successor;
 	isc_result_t result = ISC_R_SUCCESS;
-	isc_boolean_t new_origin = ISC_FALSE;
+	bool new_origin = false;
 
 	REQUIRE(VALID_CHAIN(chain) && chain->end != NULL);
 
@@ -3445,7 +3444,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 		 */
 		if (chain->level_count > 0 ||
 		    OFFSETLEN(current) > 1)
-			new_origin = ISC_TRUE;
+			new_origin = true;
 
 		ADD_LEVEL(chain, current);
 		current = DOWN(current);
@@ -3500,7 +3499,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 				}
 
 				current = chain->levels[--chain->level_count];
-				new_origin = ISC_TRUE;
+				new_origin = true;
 
 				if (RIGHT(current) != NULL)
 					break;
@@ -3540,7 +3539,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 		if (new_origin) {
 			if (origin != NULL)
-				result = chain_name(chain, origin, ISC_FALSE);
+				result = chain_name(chain, origin, false);
 
 			if (result == ISC_R_SUCCESS)
 				result = DNS_R_NEWORIGIN;
