@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -19,37 +19,14 @@
 #define RRTYPE_KEY_ATTRIBUTES \
 	( DNS_RDATATYPEATTR_ATCNAME | DNS_RDATATYPEATTR_ZONECUTAUTH )
 
-/*
- * RFC 2535 section 3.1.2 says that if bits 0-1 of the Flags field are
- * both set, it means there is no key information and the RR stops after
- * the algorithm octet.  However, this only applies to KEY records, as
- * indicated by the specifications of the RR types based on KEY:
- *
- *     CDNSKEY - RFC 7344
- *     DNSKEY - RFC 4034
- *     RKEY - draft-reid-dnsext-rkey-00
- */
-static inline bool
-generic_key_nokey(dns_rdatatype_t type, unsigned int flags) {
-	switch (type) {
-	case dns_rdatatype_cdnskey:
-	case dns_rdatatype_dnskey:
-	case dns_rdatatype_rkey:
-		return (false);
-	case dns_rdatatype_key:
-	default:
-		return ((flags & DNS_KEYFLAG_TYPEMASK) == DNS_KEYTYPE_NOKEY);
-	}
-}
-
 static inline isc_result_t
 generic_fromtext_key(ARGS_FROMTEXT) {
-	isc_result_t result;
 	isc_token_t token;
 	dns_secalg_t alg;
 	dns_secproto_t proto;
 	dns_keyflags_t flags;
 
+	UNUSED(type);
 	UNUSED(rdclass);
 	UNUSED(origin);
 	UNUSED(options);
@@ -59,9 +36,6 @@ generic_fromtext_key(ARGS_FROMTEXT) {
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
 				      false));
 	RETTOK(dns_keyflags_fromtext(&flags, &token.value.as_textregion));
-	if (type == dns_rdatatype_rkey && flags != 0U) {
-		RETTOK(DNS_R_FORMERR);
-	}
 	RETERR(uint16_tobuffer(flags, target));
 
 	/* protocol */
@@ -77,19 +51,10 @@ generic_fromtext_key(ARGS_FROMTEXT) {
 	RETERR(mem_tobuffer(target, &alg, 1));
 
 	/* No Key? */
-	if (generic_key_nokey(type, flags)) {
+	if ((flags & 0xc000) == 0xc000)
 		return (ISC_R_SUCCESS);
-	}
 
-	result = isc_base64_tobuffer(lexer, target, -2);
-	if (result != ISC_R_SUCCESS)
-		return (result);
-
-	/* Ensure there's at least enough data to compute a key ID for MD5 */
-	if (alg == DST_ALG_RSAMD5 && isc_buffer_usedlength(target) < 7)
-		return (ISC_R_UNEXPECTEDEND);
-
-	return (ISC_R_SUCCESS);
+	return (isc_base64_tobuffer(lexer, target, -2));
 }
 
 static inline isc_result_t
@@ -134,9 +99,8 @@ generic_totext_key(ARGS_TOTEXT) {
 	RETERR(str_totext(buf, target));
 
 	/* No Key? */
-	if (generic_key_nokey(rdata->type, flags)) {
+	if ((flags & 0xc000) == 0xc000)
 		return (ISC_R_SUCCESS);
-	}
 
 	if ((tctx->flags & DNS_STYLEFLAG_RRCOMMENT) != 0 &&
 	     algorithm == DNS_KEYALG_PRIVATEDNS) {
@@ -163,7 +127,7 @@ generic_totext_key(ARGS_TOTEXT) {
 	} else {
 		dns_rdata_toregion(rdata, &tmpr);
 		snprintf(buf, sizeof(buf), "[key id = %u]",
-			 dst_region_computeid(&tmpr, algorithm));
+			 dst_region_computeid(&tmpr));
 		RETERR(str_totext(buf, target));
 	}
 
@@ -187,7 +151,7 @@ generic_totext_key(ARGS_TOTEXT) {
 		RETERR(str_totext(" ; key id = ", target));
 		dns_rdata_toregion(rdata, &tmpr);
 		snprintf(buf, sizeof(buf), "%u",
-			 dst_region_computeid(&tmpr, algorithm));
+			 dst_region_computeid(&tmpr));
 		RETERR(str_totext(buf, target));
 	}
 	return (ISC_R_SUCCESS);
@@ -196,35 +160,22 @@ generic_totext_key(ARGS_TOTEXT) {
 static inline isc_result_t
 generic_fromwire_key(ARGS_FROMWIRE) {
 	unsigned char algorithm;
-	uint16_t flags;
 	isc_region_t sr;
 
+	UNUSED(type);
 	UNUSED(rdclass);
 	UNUSED(dctx);
 	UNUSED(options);
 
 	isc_buffer_activeregion(source, &sr);
-	if (sr.length < 4) {
+	if (sr.length < 4)
 		return (ISC_R_UNEXPECTEDEND);
-	}
-	flags = (sr.base[0] << 8) | sr.base[1];
-
-	if (type == dns_rdatatype_rkey && flags != 0U) {
-		return (DNS_R_FORMERR);
-	}
 
 	algorithm = sr.base[3];
 	RETERR(mem_tobuffer(target, sr.base, 4));
 	isc_region_consume(&sr, 4);
 	isc_buffer_forward(source, 4);
 
-	if (generic_key_nokey(type, flags)) {
-		return (ISC_R_SUCCESS);
-	}
-	if (sr.length == 0) {
-		return (ISC_R_UNEXPECTEDEND);
-	}
-
 	if (algorithm == DNS_KEYALG_PRIVATEDNS) {
 		dns_name_t name;
 		dns_decompress_setmethods(dctx, DNS_COMPRESS_NONE);
@@ -232,14 +183,6 @@ generic_fromwire_key(ARGS_FROMWIRE) {
 		RETERR(dns_name_fromwire(&name, source, dctx, options, target));
 	}
 
-	/*
-	 * RSAMD5 computes key ID differently from other
-	 * algorithms: we need to ensure there's enough data
-	 * present for the computation
-	 */
-	if (algorithm == DST_ALG_RSAMD5 && sr.length < 3)
-		return (ISC_R_UNEXPECTEDEND);
-
 	isc_buffer_activeregion(source, &sr);
 	isc_buffer_forward(source, sr.length);
 	return (mem_tobuffer(target, sr.base, sr.length));
@@ -306,21 +249,15 @@ compare_key(ARGS_COMPARE) {
 
 static inline isc_result_t
 generic_fromstruct_key(ARGS_FROMSTRUCT) {
-	dns_rdata_key_t *key;
+	dns_rdata_key_t *key = source;
 
-	REQUIRE(((dns_rdata_key_t *)source) != NULL);
-	REQUIRE(((dns_rdata_key_t *)source)->common.rdtype == type);
-	REQUIRE(((dns_rdata_key_t *)source)->common.rdclass == rdclass);
-
-	key = source;
+	REQUIRE(key != NULL);
+	REQUIRE(key->common.rdtype == type);
+	REQUIRE(key->common.rdclass == rdclass);
 
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	if (type == dns_rdatatype_rkey) {
-		INSIST(key->flags == 0U);
-	}
-
 	/* Flags */
 	RETERR(uint16_tobuffer(key->flags, target));
 
@@ -336,16 +273,16 @@ generic_fromstruct_key(ARGS_FROMSTRUCT) {
 
 static inline isc_result_t
 generic_tostruct_key(ARGS_TOSTRUCT) {
-	dns_rdata_key_t *key;
+	dns_rdata_key_t *key = target;
 	isc_region_t sr;
 
+	REQUIRE(rdata != NULL);
 	REQUIRE(rdata->length != 0);
-	REQUIRE(((dns_rdata_key_t *)target) != NULL);
-	REQUIRE(((dns_rdata_key_t *)target)->common.rdclass == rdata->rdclass);
-	REQUIRE(((dns_rdata_key_t *)target)->common.rdtype == rdata->type);
-	REQUIRE(!ISC_LINK_LINKED(&((dns_rdata_key_t *)target)->common, link));
 
-	key = target;
+	REQUIRE(key != NULL);
+	REQUIRE(key->common.rdclass == rdata->rdclass);
+	REQUIRE(key->common.rdtype == rdata->type);
+	REQUIRE(!ISC_LINK_LINKED(&key->common, link));
 
 	dns_rdata_toregion(rdata, &sr);
 
@@ -379,11 +316,9 @@ generic_tostruct_key(ARGS_TOSTRUCT) {
 
 static inline void
 generic_freestruct_key(ARGS_FREESTRUCT) {
-	dns_rdata_key_t *key;
+	dns_rdata_key_t *key = (dns_rdata_key_t *) source;
 
-	REQUIRE(((dns_rdata_key_t *)source) != NULL);
-
-	key = (dns_rdata_key_t *) source;
+	REQUIRE(key != NULL);
 
 	if (key->mctx == NULL)
 		return;
@@ -403,14 +338,12 @@ fromstruct_key(ARGS_FROMSTRUCT) {
 
 static inline isc_result_t
 tostruct_key(ARGS_TOSTRUCT) {
-	dns_rdata_key_t *key;
+	dns_rdata_key_t *key = target;
 
-	REQUIRE(((dns_rdata_key_t *)target) != NULL);
+	REQUIRE(key != NULL);
 	REQUIRE(rdata != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_key);
 
-	key = target;
-
 	key->common.rdclass = rdata->rdclass;
 	key->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&key->common, link);
@@ -420,9 +353,10 @@ tostruct_key(ARGS_TOSTRUCT) {
 
 static inline void
 freestruct_key(ARGS_FREESTRUCT) {
-	REQUIRE(((dns_rdata_key_t *)source) != NULL);
-	REQUIRE(((dns_rdata_key_t *)source)->common.rdtype ==
-		dns_rdatatype_key);
+	dns_rdata_key_t *key = (dns_rdata_key_t *) source;
+
+	REQUIRE(key != NULL);
+	REQUIRE(key->common.rdtype == dns_rdatatype_key);
 
 	generic_freestruct_key(source);
 }
