@@ -226,9 +226,7 @@ dns_sdb_register(const char *drivername, const dns_sdbmethods_t *methods,
 	imp->flags = flags;
 	imp->mctx = NULL;
 	isc_mem_attach(mctx, &imp->mctx);
-	result = isc_mutex_init(&imp->driverlock);
-	if (result != ISC_R_SUCCESS)
-		goto cleanup_mctx;
+	isc_mutex_init(&imp->driverlock);
 
 	imp->dbimp = NULL;
 	result = dns_db_register(drivername, dns_sdb_create, imp, mctx,
@@ -240,8 +238,7 @@ dns_sdb_register(const char *drivername, const dns_sdbmethods_t *methods,
 	return (ISC_R_SUCCESS);
 
  cleanup_mutex:
-	DESTROYLOCK(&imp->driverlock);
- cleanup_mctx:
+	isc_mutex_destroy(&imp->driverlock);
 	isc_mem_put(mctx, imp, sizeof(dns_sdbimplementation_t));
 	return (result);
 }
@@ -255,7 +252,7 @@ dns_sdb_unregister(dns_sdbimplementation_t **sdbimp) {
 
 	imp = *sdbimp;
 	dns_db_unregister(&imp->dbimp);
-	DESTROYLOCK(&imp->driverlock);
+	isc_mutex_destroy(&imp->driverlock);
 
 	mctx = imp->mctx;
 	isc_mem_put(mctx, imp, sizeof(dns_sdbimplementation_t));
@@ -557,7 +554,7 @@ destroy(dns_sdb_t *sdb) {
 	}
 
 	isc_mem_free(mctx, sdb->zone);
-	DESTROYLOCK(&sdb->lock);
+	isc_mutex_destroy(&sdb->lock);
 
 	sdb->common.magic = 0;
 	sdb->common.impmagic = 0;
@@ -655,7 +652,6 @@ closeversion(dns_db_t *db, dns_dbversion_t **versionp, bool commit) {
 static isc_result_t
 createnode(dns_sdb_t *sdb, dns_sdbnode_t **nodep) {
 	dns_sdbnode_t *node;
-	isc_result_t result;
 
 	node = isc_mem_get(sdb->common.mctx, sizeof(dns_sdbnode_t));
 	if (node == NULL)
@@ -667,11 +663,7 @@ createnode(dns_sdb_t *sdb, dns_sdbnode_t **nodep) {
 	ISC_LIST_INIT(node->buffers);
 	ISC_LINK_INIT(node, link);
 	node->name = NULL;
-	result = isc_mutex_init(&node->lock);
-	if (result != ISC_R_SUCCESS) {
-		isc_mem_put(sdb->common.mctx, node, sizeof(dns_sdbnode_t));
-		return (result);
-	}
+	isc_mutex_init(&node->lock);
 	dns_rdatacallbacks_init(&node->callbacks);
 	node->references = 1;
 	node->magic = SDBLOOKUP_MAGIC;
@@ -712,7 +704,7 @@ destroynode(dns_sdbnode_t *node) {
 		dns_name_free(node->name, mctx);
 		isc_mem_put(mctx, node->name, sizeof(dns_name_t));
 	}
-	DESTROYLOCK(&node->lock);
+	isc_mutex_destroy(&node->lock);
 	node->magic = 0;
 	isc_mem_put(mctx, node, sizeof(dns_sdbnode_t));
 	detach((dns_db_t **) (void *)&sdb);
@@ -1333,9 +1325,7 @@ dns_sdb_create(isc_mem_t *mctx, const dns_name_t *origin, dns_dbtype_t type,
 
 	isc_mem_attach(mctx, &sdb->common.mctx);
 
-	result = isc_mutex_init(&sdb->lock);
-	if (result != ISC_R_SUCCESS)
-		goto cleanup_mctx;
+	isc_mutex_init(&sdb->lock);
 
 	result = dns_name_dupwithoffsets(origin, mctx, &sdb->common.origin);
 	if (result != ISC_R_SUCCESS)
@@ -1377,8 +1367,7 @@ dns_sdb_create(isc_mem_t *mctx, const dns_name_t *origin, dns_dbtype_t type,
  cleanup_origin:
 	dns_name_free(&sdb->common.origin, mctx);
  cleanup_lock:
-	(void)isc_mutex_destroy(&sdb->lock);
- cleanup_mctx:
+	isc_mutex_destroy(&sdb->lock);
 	isc_mem_put(mctx, sdb, sizeof(dns_sdb_t));
 	isc_mem_detach(&mctx);
 
