@@ -1,27 +1,25 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id: buffer.c,v 1.49 2008/09/25 04:02:39 tbox Exp $ */
-
 /*! \file */
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
+#include <stdarg.h>
+
 #include <isc/buffer.h>
 #include <isc/mem.h>
+#include <isc/print.h>
 #include <isc/region.h>
 #include <isc/string.h>
 #include <isc/util.h>
@@ -61,8 +59,12 @@ isc_buffer_reinit(isc_buffer_t *b, void *base, unsigned int length) {
 	 */
 	REQUIRE(b->length <= length);
 	REQUIRE(base != NULL);
+	REQUIRE(!b->autore);
+
+	if (b->length > 0U) {
+		(void)memmove(base, b->base, b->length);
+	}
 
-	(void)memmove(base, b->base, b->length);
 	b->base = base;
 	b->length = length;
 }
@@ -80,6 +82,13 @@ isc__buffer_invalidate(isc_buffer_t *b) {
 	ISC__BUFFER_INVALIDATE(b);
 }
 
+void
+isc_buffer_setautorealloc(isc_buffer_t *b, bool enable) {
+	REQUIRE(ISC_BUFFER_VALID(b));
+	REQUIRE(b->mctx != NULL);
+	b->autore = enable;
+}
+
 void
 isc__buffer_region(isc_buffer_t *b, isc_region_t *r) {
 	/*
@@ -93,7 +102,7 @@ isc__buffer_region(isc_buffer_t *b, isc_region_t *r) {
 }
 
 void
-isc__buffer_usedregion(isc_buffer_t *b, isc_region_t *r) {
+isc__buffer_usedregion(const isc_buffer_t *b, isc_region_t *r) {
 	/*
 	 * Make 'r' refer to the used region of 'b'.
 	 */
@@ -249,7 +258,9 @@ isc_buffer_compact(isc_buffer_t *b) {
 
 	src = isc_buffer_current(b);
 	length = isc_buffer_remaininglength(b);
-	(void)memmove(b->base, src, (size_t)length);
+	if (length > 0U) {
+		(void)memmove(b->base, src, (size_t)length);
+	}
 
 	if (b->active > b->current)
 		b->active -= b->current;
@@ -259,10 +270,10 @@ isc_buffer_compact(isc_buffer_t *b) {
 	b->used = length;
 }
 
-isc_uint8_t
+uint8_t
 isc_buffer_getuint8(isc_buffer_t *b) {
 	unsigned char *cp;
-	isc_uint8_t result;
+	uint8_t result;
 
 	/*
 	 * Read an unsigned 8-bit integer from 'b' and return it.
@@ -273,23 +284,28 @@ isc_buffer_getuint8(isc_buffer_t *b) {
 
 	cp = isc_buffer_current(b);
 	b->current += 1;
-	result = ((isc_uint8_t)(cp[0]));
+	result = ((uint8_t)(cp[0]));
 
 	return (result);
 }
 
 void
-isc__buffer_putuint8(isc_buffer_t *b, isc_uint8_t val) {
+isc__buffer_putuint8(isc_buffer_t *b, uint8_t val) {
+	isc_result_t result;
 	REQUIRE(ISC_BUFFER_VALID(b));
-	REQUIRE(b->used + 1 <= b->length);
+	if (ISC_UNLIKELY(b->autore)) {
+		result = isc_buffer_reserve(&b, 1);
+		REQUIRE(result == ISC_R_SUCCESS);
+	}
+	REQUIRE(isc_buffer_availablelength(b) >= 1);
 
 	ISC__BUFFER_PUTUINT8(b, val);
 }
 
-isc_uint16_t
+uint16_t
 isc_buffer_getuint16(isc_buffer_t *b) {
 	unsigned char *cp;
-	isc_uint16_t result;
+	uint16_t result;
 
 	/*
 	 * Read an unsigned 16-bit integer in network byte order from 'b',
@@ -308,25 +324,35 @@ isc_buffer_getuint16(isc_buffer_t *b) {
 }
 
 void
-isc__buffer_putuint16(isc_buffer_t *b, isc_uint16_t val) {
+isc__buffer_putuint16(isc_buffer_t *b, uint16_t val) {
+	isc_result_t result;
 	REQUIRE(ISC_BUFFER_VALID(b));
-	REQUIRE(b->used + 2 <= b->length);
+	if (ISC_UNLIKELY(b->autore)) {
+		result = isc_buffer_reserve(&b, 2);
+		REQUIRE(result == ISC_R_SUCCESS);
+	}
+	REQUIRE(isc_buffer_availablelength(b) >= 2);
 
 	ISC__BUFFER_PUTUINT16(b, val);
 }
 
 void
-isc__buffer_putuint24(isc_buffer_t *b, isc_uint32_t val) {
+isc__buffer_putuint24(isc_buffer_t *b, uint32_t val) {
+	isc_result_t result;
 	REQUIRE(ISC_BUFFER_VALID(b));
-	REQUIRE(b->used + 3 <= b->length);
+	if (ISC_UNLIKELY(b->autore)) {
+		result = isc_buffer_reserve(&b, 3);
+		REQUIRE(result == ISC_R_SUCCESS);
+	}
+	REQUIRE(isc_buffer_availablelength(b) >= 3);
 
 	ISC__BUFFER_PUTUINT24(b, val);
 }
 
-isc_uint32_t
+uint32_t
 isc_buffer_getuint32(isc_buffer_t *b) {
 	unsigned char *cp;
-	isc_uint32_t result;
+	uint32_t result;
 
 	/*
 	 * Read an unsigned 32-bit integer in network byte order from 'b',
@@ -347,17 +373,22 @@ isc_buffer_getuint32(isc_buffer_t *b) {
 }
 
 void
-isc__buffer_putuint32(isc_buffer_t *b, isc_uint32_t val) {
+isc__buffer_putuint32(isc_buffer_t *b, uint32_t val) {
+	isc_result_t result;
 	REQUIRE(ISC_BUFFER_VALID(b));
-	REQUIRE(b->used + 4 <= b->length);
+	if (ISC_UNLIKELY(b->autore)) {
+		result = isc_buffer_reserve(&b, 4);
+		REQUIRE(result == ISC_R_SUCCESS);
+	}
+	REQUIRE(isc_buffer_availablelength(b) >= 4);
 
 	ISC__BUFFER_PUTUINT32(b, val);
 }
 
-isc_uint64_t
+uint64_t
 isc_buffer_getuint48(isc_buffer_t *b) {
 	unsigned char *cp;
-	isc_uint64_t result;
+	uint64_t result;
 
 	/*
 	 * Read an unsigned 48-bit integer in network byte order from 'b',
@@ -369,26 +400,31 @@ isc_buffer_getuint48(isc_buffer_t *b) {
 
 	cp = isc_buffer_current(b);
 	b->current += 6;
-	result = ((isc_int64_t)(cp[0])) << 40;
-	result |= ((isc_int64_t)(cp[1])) << 32;
-	result |= ((isc_int64_t)(cp[2])) << 24;
-	result |= ((isc_int64_t)(cp[3])) << 16;
-	result |= ((isc_int64_t)(cp[4])) << 8;
-	result |= ((isc_int64_t)(cp[5]));
+	result = ((int64_t)(cp[0])) << 40;
+	result |= ((int64_t)(cp[1])) << 32;
+	result |= ((int64_t)(cp[2])) << 24;
+	result |= ((int64_t)(cp[3])) << 16;
+	result |= ((int64_t)(cp[4])) << 8;
+	result |= ((int64_t)(cp[5]));
 
 	return (result);
 }
 
 void
-isc__buffer_putuint48(isc_buffer_t *b, isc_uint64_t val) {
-	isc_uint16_t valhi;
-	isc_uint32_t vallo;
+isc__buffer_putuint48(isc_buffer_t *b, uint64_t val) {
+	isc_result_t result;
+	uint16_t valhi;
+	uint32_t vallo;
 
 	REQUIRE(ISC_BUFFER_VALID(b));
-	REQUIRE(b->used + 6 <= b->length);
+	if (ISC_UNLIKELY(b->autore)) {
+		result = isc_buffer_reserve(&b, 6);
+		REQUIRE(result == ISC_R_SUCCESS);
+	}
+	REQUIRE(isc_buffer_availablelength(b) >= 6);
 
-	valhi = (isc_uint16_t)(val >> 32);
-	vallo = (isc_uint32_t)(val & 0xFFFFFFFF);
+	valhi = (uint16_t)(val >> 32);
+	vallo = (uint32_t)(val & 0xFFFFFFFF);
 	ISC__BUFFER_PUTUINT16(b, valhi);
 	ISC__BUFFER_PUTUINT32(b, vallo);
 }
@@ -397,8 +433,13 @@ void
 isc__buffer_putmem(isc_buffer_t *b, const unsigned char *base,
 		   unsigned int length)
 {
+	isc_result_t result;
 	REQUIRE(ISC_BUFFER_VALID(b));
-	REQUIRE(b->used + length <= b->length);
+	if (ISC_UNLIKELY(b->autore)) {
+		result = isc_buffer_reserve(&b, length);
+		REQUIRE(result == ISC_R_SUCCESS);
+	}
+	REQUIRE(isc_buffer_availablelength(b) >= length);
 
 	ISC__BUFFER_PUTMEM(b, base, length);
 }
@@ -407,6 +448,7 @@ void
 isc__buffer_putstr(isc_buffer_t *b, const char *source) {
 	unsigned int l;
 	unsigned char *cp;
+	isc_result_t result;
 
 	REQUIRE(ISC_BUFFER_VALID(b));
 	REQUIRE(source != NULL);
@@ -415,31 +457,83 @@ isc__buffer_putstr(isc_buffer_t *b, const char *source) {
 	 * Do not use ISC__BUFFER_PUTSTR(), so strlen is only done once.
 	 */
 	l = strlen(source);
-
-	REQUIRE(l <= isc_buffer_availablelength(b));
+	if (ISC_UNLIKELY(b->autore)) {
+		result = isc_buffer_reserve(&b, l);
+		REQUIRE(result == ISC_R_SUCCESS);
+	}
+	REQUIRE(isc_buffer_availablelength(b) >= l);
 
 	cp = isc_buffer_used(b);
 	memmove(cp, source, l);
 	b->used += l;
 }
 
+void
+isc_buffer_putdecint(isc_buffer_t *b, int64_t v) {
+	unsigned int l=0;
+	unsigned char *cp;
+	char buf[21];
+	isc_result_t result;
+
+	REQUIRE(ISC_BUFFER_VALID(b));
+
+	/* xxxwpk do it more low-level way ? */
+	l = snprintf(buf, 21, "%" PRId64, v);
+	RUNTIME_CHECK(l <= 21);
+	if (ISC_UNLIKELY(b->autore)) {
+		result = isc_buffer_reserve(&b, l);
+		REQUIRE(result == ISC_R_SUCCESS);
+	}
+	REQUIRE(isc_buffer_availablelength(b) >= l);
+
+	cp = isc_buffer_used(b);
+	memmove(cp, buf, l);
+	b->used += l;
+}
+
+isc_result_t
+isc_buffer_dup(isc_mem_t *mctx, isc_buffer_t **dstp, const isc_buffer_t *src) {
+	isc_buffer_t *dst = NULL;
+	isc_region_t region;
+	isc_result_t result;
+
+	REQUIRE(dstp != NULL && *dstp == NULL);
+	REQUIRE(ISC_BUFFER_VALID(src));
+
+	isc_buffer_usedregion(src, &region);
+
+	result = isc_buffer_allocate(mctx, &dst, region.length);
+	if (result != ISC_R_SUCCESS)
+		return (result);
+
+	result = isc_buffer_copyregion(dst, &region);
+	RUNTIME_CHECK(result == ISC_R_SUCCESS); /* NOSPACE is impossible */
+	*dstp = dst;
+	return (ISC_R_SUCCESS);
+}
+
 isc_result_t
 isc_buffer_copyregion(isc_buffer_t *b, const isc_region_t *r) {
-	unsigned char *base;
-	unsigned int available;
+	isc_result_t result;
 
 	REQUIRE(ISC_BUFFER_VALID(b));
 	REQUIRE(r != NULL);
 
-	/*
-	 * XXXDCL
-	 */
-	base = isc_buffer_used(b);
-	available = isc_buffer_availablelength(b);
-	if (r->length > available)
+	if (ISC_UNLIKELY(b->autore)) {
+		result = isc_buffer_reserve(&b, r->length);
+		if (result != ISC_R_SUCCESS) {
+			return (result);
+		}
+	}
+
+	if (r->length > isc_buffer_availablelength(b)) {
 		return (ISC_R_NOSPACE);
-	memmove(base, r->base, r->length);
-	b->used += r->length;
+	}
+
+	if (r->length > 0U) {
+		memmove(isc_buffer_used(b), r->base, r->length);
+		b->used += r->length;
+	}
 
 	return (ISC_R_SUCCESS);
 }
@@ -449,16 +543,21 @@ isc_buffer_allocate(isc_mem_t *mctx, isc_buffer_t **dynbuffer,
 		    unsigned int length)
 {
 	isc_buffer_t *dbuf;
-
+	unsigned char * bdata;
 	REQUIRE(dynbuffer != NULL);
 	REQUIRE(*dynbuffer == NULL);
 
-	dbuf = isc_mem_get(mctx, length + sizeof(isc_buffer_t));
+	dbuf = isc_mem_get(mctx, sizeof(isc_buffer_t));
 	if (dbuf == NULL)
 		return (ISC_R_NOMEMORY);
 
-	isc_buffer_init(dbuf, ((unsigned char *)dbuf) + sizeof(isc_buffer_t),
-			length);
+	bdata = isc_mem_get(mctx, length);
+	if (bdata == NULL) {
+		isc_mem_put(mctx, dbuf, sizeof(isc_buffer_t));
+		return (ISC_R_NOMEMORY);
+	}
+
+	isc_buffer_init(dbuf, bdata, length);
 	dbuf->mctx = mctx;
 
 	ENSURE(ISC_BUFFER_VALID(dbuf));
@@ -468,9 +567,58 @@ isc_buffer_allocate(isc_mem_t *mctx, isc_buffer_t **dynbuffer,
 	return (ISC_R_SUCCESS);
 }
 
+isc_result_t
+isc_buffer_reserve(isc_buffer_t **dynbuffer, unsigned int size) {
+	unsigned char *bdata;
+	uint64_t len;
+
+	REQUIRE(dynbuffer != NULL);
+	REQUIRE(ISC_BUFFER_VALID(*dynbuffer));
+
+	len = (*dynbuffer)->length;
+	if ((len - (*dynbuffer)->used) >= size) {
+		return (ISC_R_SUCCESS);
+	}
+
+	if ((*dynbuffer)->mctx == NULL) {
+		return (ISC_R_NOSPACE);
+	}
+
+	/* Round to nearest buffer size increment */
+	len = size + (*dynbuffer)->used;
+	len = (len + ISC_BUFFER_INCR - 1 - ((len - 1) % ISC_BUFFER_INCR));
+
+	/* Cap at UINT_MAX */
+	if (len > UINT_MAX) {
+		len = UINT_MAX;
+	}
+
+	if ((len - (*dynbuffer)->used) < size) {
+		return (ISC_R_NOMEMORY);
+	}
+
+	/*
+	 * XXXMUKS: This is far more expensive than plain realloc() as
+	 * it doesn't remap pages, but does ordinary copy. So is
+	 * isc_mem_reallocate(), which has additional issues.
+	 */
+	bdata = isc_mem_get((*dynbuffer)->mctx, (unsigned int) len);
+	if (bdata == NULL) {
+		return (ISC_R_NOMEMORY);
+	}
+
+	memmove(bdata, (*dynbuffer)->base, (*dynbuffer)->length);
+	isc_mem_put((*dynbuffer)->mctx, (*dynbuffer)->base,
+		    (*dynbuffer)->length);
+
+	(*dynbuffer)->base = bdata;
+	(*dynbuffer)->length = (unsigned int) len;
+
+	return (ISC_R_SUCCESS);
+}
+
 void
 isc_buffer_free(isc_buffer_t **dynbuffer) {
-	unsigned int real_length;
 	isc_buffer_t *dbuf;
 	isc_mem_t *mctx;
 
@@ -480,11 +628,50 @@ isc_buffer_free(isc_buffer_t **dynbuffer) {
 
 	dbuf = *dynbuffer;
 	*dynbuffer = NULL;	/* destroy external reference */
-
-	real_length = dbuf->length + sizeof(isc_buffer_t);
 	mctx = dbuf->mctx;
 	dbuf->mctx = NULL;
-	isc_buffer_invalidate(dbuf);
 
-	isc_mem_put(mctx, dbuf, real_length);
+	isc_mem_put(mctx, dbuf->base, dbuf->length);
+	isc_buffer_invalidate(dbuf);
+	isc_mem_put(mctx, dbuf, sizeof(isc_buffer_t));
+}
+
+isc_result_t
+isc_buffer_printf(isc_buffer_t *b, const char *format, ...) {
+	va_list ap;
+	int n;
+	isc_result_t result;
+
+	REQUIRE(ISC_BUFFER_VALID(b));
+
+	va_start(ap, format);
+	n = vsnprintf(NULL, 0, format, ap);
+	va_end(ap);
+
+	if (n < 0) {
+		return (ISC_R_FAILURE);
+	}
+
+	if (ISC_UNLIKELY(b->autore)) {
+		result = isc_buffer_reserve(&b, n + 1);
+		if (result != ISC_R_SUCCESS) {
+			return (result);
+		}
+	}
+
+	if (isc_buffer_availablelength(b) < (unsigned int)n + 1) {
+		return (ISC_R_NOSPACE);
+	}
+
+	va_start(ap, format);
+	n = vsnprintf(isc_buffer_used(b), n + 1, format, ap);
+	va_end(ap);
+
+	if (n < 0) {
+		return (ISC_R_FAILURE);
+	}
+
+	b->used += n;
+
+	return (ISC_R_SUCCESS);
 }
